==> apigee_devportal_kickstart-2.1.2.zip: apigee_devportal_kickstart/README.md <==
# Apigee Developer Portal Kickstart

[Apigee Developer Portal Kickstart](http://drupal.org/project/apigee_devportal_kickstart) is a Drupal distribution that allows to quickly try out or get started using Drupal to create an Apigee developer portal.

This project is a [Drupal installation profile](https://www.drupal.org/docs/8/distributions) which needs to be added to Drupal core and installed using [Composer](https://getcomposer.org). The [installation instructions](https://www.drupal.org/docs/8/modules/apigee-developer-portal-kickstart/get-started-with-kickstart)  use the [Apigee Developer Portal Kickstart Composer project](https://github.com/apigee/devportal-kickstart-project-composer) to install Drupal core and this installation profile to create a site.

## Project status

The core functionality of this profile is in active development. The features and functionality will evolve as the project grows. We encourage you to download and evaluate the profile, and to use our [GitHub issue queue](https://github.com/apigee/apigee-devportal-kickstart-drupal/issues) to give feedback, ask questions, or log issues.

## Customizing the look and feel
Information on how to customize the look and feel of the site can be found in the subtheme's README at: `themes/custom/apigee_kickstart/README.md`.

## Documentation

Full documentation is up on the [Drupal.org Apigee Developer Portal Kickstart profile documentation page](https://www.drupal.org/docs/8/modules/apigee-developer-portal-kickstart).

## Issues, questions and feedback

We encourage anyone with feedback, questions or issues to put in an issue into
our [GitHub issue queue](https://github.com/apigee/apigee-devportal-kickstart-drupal/issues).

## Known issues

There are no known issues at this time.

## Contribute

We'd love to accept your patches and contributions to this project. Make sure to read [CONTRIBUTING.md](CONTRIBUTING.md) for details.
Development is happening in our [GitHub repository](https://github.com/apigee/apigee-devportal-kickstart-drupal). The drupal.org issue
queue is disabled, we use the [GitHub issue queue](https://github.com/apigee/apigee-devportal-kickstart-drupal/issues) instead.

## Support

This project, which integrates Drupal 9 and Drupal 8 with Apigee, is supported by Google.

==> apigee_devportal_kickstart-3.0.3.zip: apigee_devportal_kickstart/README.md <==
# Apigee Developer Portal Kickstart

[Apigee Developer Portal Kickstart](http://drupal.org/project/apigee_devportal_kickstart) is a Drupal distribution that allows to quickly try out or get started using Drupal to create an Apigee developer portal.

This project is a [Drupal installation profile](https://www.drupal.org/docs/8/distributions) which needs to be added to Drupal core and installed using [Composer](https://getcomposer.org). The [installation instructions](https://www.drupal.org/docs/8/modules/apigee-developer-portal-kickstart/get-started-with-kickstart)  use the [Apigee Developer Portal Kickstart Composer project](https://github.com/apigee/devportal-kickstart-project-composer) to install Drupal core and this installation profile to create a site.

## Project status

The core functionality of this profile is in active development. The features and functionality will evolve as the project grows. We encourage you to download and evaluate the profile, and to use our [GitHub issue queue](https://github.com/apigee/apigee-devportal-kickstart-drupal/issues) to give feedback, ask questions, or log issues.

## Customizing the look and feel
Information on how to customize the look and feel of the site can be found in the subtheme's README at: `themes/custom/apigee_kickstart/README.md`.

## Documentation

Full documentation is up on the [Drupal.org Apigee Developer Portal Kickstart profile documentation page](https://www.drupal.org/docs/8/modules/apigee-developer-portal-kickstart).

## Upgrade from Drupal 9 to Drupal 10

Refer the [documentation](https://www.drupal.org/docs/contributed-modules/apigee-developer-portal-kickstart/upgrade-from-drupal-9-to-drupal-10) for upgrading from Drupal 9 to Drupal 10.

## Issues, questions and feedback

We encourage anyone with feedback, questions or issues to put in an issue into
our [GitHub issue queue](https://github.com/apigee/apigee-devportal-kickstart-drupal/issues).

## Known issues

There are no known issues at this time.

## Contribute

We'd love to accept your patches and contributions to this project. Make sure to read [CONTRIBUTING.md](CONTRIBUTING.md) for details.
Development is happening in our [GitHub repository](https://github.com/apigee/apigee-devportal-kickstart-drupal). The drupal.org issue
queue is disabled, we use the [GitHub issue queue](https://github.com/apigee/apigee-devportal-kickstart-drupal/issues) instead.

## Support

This project, which integrates Drupal 9 and Drupal 8 with Apigee, is supported by Google.
